@@ -4,19 +4,11 @@ import types
 import inspect
 import payload
 
-def objects_module_to_dict(module):
-    objects = {}
-
-    for name in dir(module):
-        attr = getattr(module, name)
-
-        if not inspect.isclass(attr)\
-        or not issubclass(attr, ARMObject):
-            pass
-
-        objects[name] = attr
-
-    return objects
+def get_object(objects, name):
+    if isinstance(objects, dict):
+        return objects[name]
+    else:
+        return getattr(objects, name)
 
 class Session(object):
     def __init__(self, api_key=None, api_url=None):
@@ -33,9 +25,7 @@ class Session(object):
         return ARMRequest(session=self).delete(*args, **kwargs)
 
     def __getattr__(self, name):
-        return ARMObjectWrapper(self._objects[name], self)
+        return ARMObjectWrapper(get_object(self._objects, name), self)
 
 def session_factory(name, objects):
-    if isinstance(objects, types.ModuleType):
-        objects = objects_module_to_dict(objects)
     return type(name, (Session,), {'_objects': objects})
